@@ -1,4 +1,4 @@
-from FreeTAKServer.controllers.DatabaseControllers.TableController import TableController
+from FreeTAKServer.controllers.DatabaseControllers.table_controllers import TableController
 from FreeTAKServer.model.SQLAlchemy.Event import Event
 import importlib
 
@@ -10,8 +10,9 @@ class EventTableController(TableController):
         row = self.convert_model_to_row(modelObject=object)
         session.add(row)
         session.commit()
+        return row
 
-    def convert_model_to_row(self, modelObject, rowObject = None):
+    def convert_model_to_row(self, modelObject, rowObject = None, parentRowObject = None):
         # TODO: find a more elegant way of doing this
         if rowObject == None:
             rowObject = Event()
@@ -20,14 +21,16 @@ class EventTableController(TableController):
         for attribName, attribValue in modelObject.__dict__.items():
             if hasattr(attribValue, '__dict__'):
                 if attribName[0].isalpha():
-                    pass
+                    attribName = attribName[0].upper()+attribName[1:]
                 else:
-                    attribName[1].capitalize()
+                    attribName = '_'+attribName[1].upper()+attribName[2:]
+
                 subRowObjectImport = importlib.import_module(
-                    f'FreeTAKServer.model.SQLAlchemy.CoTTables.{attribName.capitalize()}')
-                subRowObject = getattr(subRowObjectImport, attribName.capitalize())()
-                subTableRowObject = self.convert_model_to_row(attribValue, subRowObject)
-                setattr(rowObject, attribName, subTableRowObject)
+                    f'FreeTAKServer.model.SQLAlchemy.CoTTables.{attribName}')
+
+                subRowObject = getattr(subRowObjectImport, attribName)()
+                subTableRowObject = self.convert_model_to_row(attribValue, subRowObject, rowObject)
+                #setattr(rowObject, attribName, subTableRowObject)
 
             elif isinstance(attribValue, list):
                 if attribName[0].isalpha():
@@ -43,4 +46,6 @@ class EventTableController(TableController):
 
             else:
                 setattr(rowObject, attribName, attribValue)
+        if parentRowObject != None:
+            setattr(rowObject, parentRowObject.__class__.__name__, parentRowObject)
         return rowObject
\ No newline at end of file
