@@ -2,6 +2,7 @@ from abc import ABC, abstractmethod
 import logging
 import selectors
 import multiprocessing
+from defusedxml import ElementTree as etree
 
 from FreeTAKServer.controllers.DatabaseControllers.DatabaseController import DatabaseController
 
@@ -34,14 +35,17 @@ class FederationServiceBase(ServerServiceInterface, ServiceBase):
         Returns:
 
         """
-        modelObject = XMLCoTController().determine_model_object_type(protobuf_object.event.type)  # pylint: disable=no-member; member does exist
-        fts_obj = ProtobufSerializer().from_format_to_fts_object(protobuf_object, modelObject())
-        event = XmlSerializer().from_fts_object_to_format(fts_obj)
+        model_object, fts_object = XMLCoTController().determine_model_object_type(protobuf_object.event.type)  # pylint: disable=no-member; member does exist
+        fts_object = fts_object()
+        model_object = ProtobufSerializer().from_format_to_fts_object(protobuf_object, model_object())
+        xml_object = XmlSerializer().from_fts_object_to_format(model_object)
+        fts_object.setModelObject(model_object)
+        fts_object.setXmlString(etree.tostring(xml_object))
         """xmlstring = event
         if xmlstring.find('detail') and xmlstring.find('detail').
         xmlstring.find('detail').remove(xmlstring.find('detail').find('remarks'))
         xmlstring.find('detail').extend([child for child in xmlstring.find('detail')])"""
-        return fts_obj, event
+        return fts_object
 
     def _get_header_length(self, header):
         return int.from_bytes(header, 'big')
